==> CSBS-VBS-Upgrade-Plugin-8.3.0.zip: CSBS/scripts/upgrade/karbor/sub_job_pre_check_version.py <==
import os

import utils.common.log as logger
from utils.business.project_util import ProjectApi
from utils.common.check_result import CheckResult
from utils.common.message import Message

from plugins.CSBS.common.util import ConfigIniFile
from plugins.CSBS.scripts.upgrade.karbor.base import BaseSubJob

logger.init("CSBS-VBS")


class PreCheckVersion(BaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(PreCheckVersion, self).__init__(project_id, pod_id,
                                              regionid_list)
        self.original_version = self.upgrade_path.original_version
        self.current_version = self.upgrade_path.current_version
        self.target_version = self.upgrade_path.target_version
        self.project_api = ProjectApi()

    def execute(self, project_id, pod_id, regionid_list=None):
        logger.info("Init version information data.")
        self._init_karbor_version_param()
        logger.info("Succeeded to init version information data.")
        # check version before upgrade
        item_dict = self.params_store.get_check_config("PerCheckVersion")
        check_results = []
        logger.info(
            f"original_version:{self.original_version},current_version:{self.current_version},"
            f"target_version:{self.target_version}")
        if self._check_version():
            result = CheckResult(itemname_ch=item_dict["itemname_ch"],
                                 itemname_en=item_dict["itemname_en"],
                                 status=item_dict["success_status"])
            check_results.append(result)
        else:
            result = CheckResult(
                itemname_ch=item_dict["itemname_ch"],
                itemname_en=item_dict["itemname_en"],
                status=item_dict["failure_status"],
                error_msg_cn=item_dict["error_msg_cn"].format(
                    self.original_version,
                    str(self.current_version)),
                error_msg_en=item_dict["error_msg_en"].format(
                    self.original_version,
                    str(self.current_version)),
                suggestion_cn=item_dict["suggestion_cn"],
                suggestion_en=item_dict["suggestion_en"])
            check_results.append(result)
        logger.info("Check Karbor version succeed.")
        # save pre-upgrade and post-upgrade versions
        version_info = {
            "Originalversion": self.original_version,
            "Targetversion": self.target_version
        }
        self.project_api.save_version_info(self.project_id, "CSBS-VBS", version_info)
        return Message(200, check_results=check_results)

    def _check_version(self):
        if self.original_version <= self.current_version <= self.target_version:
            return True
        elif self.current_version == "8.3.RC1" and self.target_version == "8.3.0":
            return True
        else:
            return False

    def _init_karbor_version_param(self):
        env_config_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                                       "../../../conf/upgrade/env_param.ini")
        conf_env_file = ConfigIniFile(env_config_path)
        ret = conf_env_file.set_value_by_key_and_sub_key("karbor", "original_version",
                                                         self.upgrade_path.karbor_full_version)
        if not ret:
            raise Exception("Failed to save the karbor current version.")
        ret = conf_env_file.set_value_by_key_and_sub_key("karbor", "target_version",
                                                         self.upgrade_path.karbor_pkg_version)
        if not ret:
            raise Exception("Failed to save the karbor target version.")

==> CSBS-VBS-Upgrade-Plugin-8.3.1.zip: CSBS/scripts/upgrade/karbor/sub_job_pre_check_version.py <==
import os

import utils.common.log as logger
from utils.business.project_util import ProjectApi
from utils.common.check_result import CheckResult
from utils.common.message import Message

from plugins.CSBS.common.util import ConfigIniFile
from plugins.CSBS.scripts.upgrade.karbor.base import BaseSubJob

logger.init("CSBS-VBS")


class PreCheckVersion(BaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(PreCheckVersion, self).__init__(project_id, pod_id,
                                              regionid_list)
        self.original_version = self.upgrade_path.original_version
        self.current_version = self.upgrade_path.current_version
        self.target_version = self.upgrade_path.target_version
        self.project_api = ProjectApi()

    def execute(self, project_id, pod_id, regionid_list=None):
        logger.info("Init version information data.")
        self._init_karbor_version_param()
        logger.info("Succeeded to init version information data.")
        # check version before upgrade
        item_dict = self.params_store.get_check_config("PerCheckVersion")
        check_results = []
        logger.info(
            f"original_version:{self.original_version},current_version:{self.current_version},"
            f"target_version:{self.target_version}")
        if self._check_karbor_current_version_within_upgrade_path():
            result = CheckResult(itemname_ch=item_dict["itemname_ch"],
                                 itemname_en=item_dict["itemname_en"],
                                 status=item_dict["success_status"])
            check_results.append(result)
        else:
            result = CheckResult(
                itemname_ch=item_dict["itemname_ch"],
                itemname_en=item_dict["itemname_en"],
                status=item_dict["failure_status"],
                error_msg_cn=item_dict["error_msg_cn"].format(
                    self.original_version,
                    str(self.current_version)),
                error_msg_en=item_dict["error_msg_en"].format(
                    self.original_version,
                    str(self.current_version)),
                suggestion_cn=item_dict["suggestion_cn"],
                suggestion_en=item_dict["suggestion_en"])
            check_results.append(result)
        logger.info("Check Karbor version finished.")
        # save pre-upgrade and post-upgrade versions
        version_info = {
            "Originalversion": self.original_version,
            "Targetversion": self.target_version
        }
        self.project_api.save_version_info(self.project_id, "CSBS-VBS", version_info)
        return Message(200, check_results=check_results)

    def _check_karbor_current_version_within_upgrade_path(self):
        return self.original_version <= self.current_version <= self.target_version

    def _init_karbor_version_param(self):
        env_config_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                                       "../../../conf/upgrade/env_param.ini")
        conf_env_file = ConfigIniFile(env_config_path)
        ret = conf_env_file.set_value_by_key_and_sub_key("karbor", "original_version",
                                                         self.upgrade_path.karbor_full_version)
        if not ret:
            raise Exception("Failed to save the karbor current version.")
        ret = conf_env_file.set_value_by_key_and_sub_key("karbor", "target_version",
                                                         self.upgrade_path.karbor_pkg_version)
        if not ret:
            raise Exception("Failed to save the karbor target version.")
